==> jc-1.4.0.tar.gz: soot/jimple/internal/JNewMultiArrayExpr.h <==
// public class soot.jimple.internal.JNewMultiArrayExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f1308ce4deac7989 soot_jimple_internal_AbstractNewMultiArrayExpr
// @dep_class a917d05d8967b1c soot_jimple_internal_JNewMultiArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewMultiArrayExpr

#include "soot/jimple/internal/AbstractNewMultiArrayExpr.h"

#ifndef _JC_soot_jimple_internal_JNewMultiArrayExpr_H_
#define _JC_soot_jimple_internal_JNewMultiArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_ArrayType$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_refs	_jc_soot_jimple_internal_JNewMultiArrayExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_nonrefs	_jc_soot_jimple_internal_JNewMultiArrayExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$refs	_jc_soot_jimple_internal_JNewMultiArrayExpr$refs;
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$nonrefs	_jc_soot_jimple_internal_JNewMultiArrayExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object	_jc_soot_jimple_internal_JNewMultiArrayExpr$object;

typedef const struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vmethods	_jc_soot_jimple_internal_JNewMultiArrayExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vtable	_jc_soot_jimple_internal_JNewMultiArrayExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vtype	_jc_soot_jimple_internal_JNewMultiArrayExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JNewMultiArrayExpr$method$_init$6d5b986214f5a4a4(_jc_env *, struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object *, struct _jc_soot_ArrayType$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JNewMultiArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JNewMultiArrayExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewMultiArrayExpr$vmethods	soot_jimple_internal_AbstractNewMultiArrayExpr;
	_jc_soot_jimple_internal_JNewMultiArrayExpr$vmethods	soot_jimple_internal_JNewMultiArrayExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JNewMultiArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$refs {
    _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_refs	soot_jimple_internal_JNewMultiArrayExpr;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_refs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_nonrefs	soot_jimple_internal_JNewMultiArrayExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object {
	_jc_soot_jimple_internal_JNewMultiArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JNewMultiArrayExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JNewMultiArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JNewMultiArrayExpr$vtype _jc_soot_jimple_internal_JNewMultiArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JNewMultiArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JNewMultiArrayExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JNewMultiArrayExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JNewMultiArrayExpr.h <==
// public class soot.jimple.internal.JNewMultiArrayExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f1308ce4deac7989 soot_jimple_internal_AbstractNewMultiArrayExpr
// @dep_class a917d05d8967b1c soot_jimple_internal_JNewMultiArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewMultiArrayExpr

#include "soot/jimple/internal/AbstractNewMultiArrayExpr.h"

#ifndef _JC_soot_jimple_internal_JNewMultiArrayExpr_H_
#define _JC_soot_jimple_internal_JNewMultiArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_ArrayType$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_refs	_jc_soot_jimple_internal_JNewMultiArrayExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_nonrefs	_jc_soot_jimple_internal_JNewMultiArrayExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$refs	_jc_soot_jimple_internal_JNewMultiArrayExpr$refs;
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$nonrefs	_jc_soot_jimple_internal_JNewMultiArrayExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object	_jc_soot_jimple_internal_JNewMultiArrayExpr$object;

typedef const struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vmethods	_jc_soot_jimple_internal_JNewMultiArrayExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vtable	_jc_soot_jimple_internal_JNewMultiArrayExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vtype	_jc_soot_jimple_internal_JNewMultiArrayExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JNewMultiArrayExpr$method$_init$6d5b986214f5a4a4(_jc_env *, struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object *, struct _jc_soot_ArrayType$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JNewMultiArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JNewMultiArrayExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewMultiArrayExpr$vmethods	soot_jimple_internal_AbstractNewMultiArrayExpr;
	_jc_soot_jimple_internal_JNewMultiArrayExpr$vmethods	soot_jimple_internal_JNewMultiArrayExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JNewMultiArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$refs {
    _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_refs	soot_jimple_internal_JNewMultiArrayExpr;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_refs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_soot_jimple_internal_JNewMultiArrayExpr$sub_nonrefs	soot_jimple_internal_JNewMultiArrayExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JNewMultiArrayExpr$object {
	_jc_soot_jimple_internal_JNewMultiArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JNewMultiArrayExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JNewMultiArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JNewMultiArrayExpr$vtype _jc_soot_jimple_internal_JNewMultiArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JNewMultiArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JNewMultiArrayExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JNewMultiArrayExpr_H_ */
